==> jakarta-faces-tck-4.0.1.zip: faces-tck-4.0.1/tck/faces23/systemEvent/src/main/java/ee/jakarta/tck/faces/test/servlet40/systemevent/PostRenderViewEventBean.java <==
/*
 * Copyright (c) 1997, 2018 Oracle and/or its affiliates. All rights reserved.
 * Copyright (c) 2020 Contributors to Eclipse Foundation.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package ee.jakarta.tck.faces.test.servlet40.systemevent;

import java.io.IOException;

import jakarta.enterprise.context.RequestScoped;
import jakarta.faces.annotation.FacesConfig;
import jakarta.faces.context.ExternalContext;
import jakarta.faces.event.ComponentSystemEvent;
import jakarta.inject.Inject;
import jakarta.inject.Named;

@Named
@RequestScoped
public class PostRenderViewEventBean {

    @Inject
    private ExternalContext externalContext;

    public void pre(ComponentSystemEvent event) throws IOException {
        externalContext.getResponseOutputWriter().write("<!-- pre -->");
    }

    public String getRender() {
        return "render";
    }

    public void post(ComponentSystemEvent event) throws IOException {
        externalContext.getResponseOutputWriter().write("<!-- post -->");
    }
}

==> jakarta-faces-tck-4.0.4.zip: faces-tck-4.0.4/tck/faces23/systemEvent/src/main/java/ee/jakarta/tck/faces/test/servlet40/systemevent/PostRenderViewEventBean.java <==
/*
 * Copyright (c) 1997, 2018 Oracle and/or its affiliates. All rights reserved.
 * Copyright (c) 2020 Contributors to Eclipse Foundation.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package ee.jakarta.tck.faces.test.servlet40.systemevent;

import java.io.IOException;

import jakarta.enterprise.context.RequestScoped;
import jakarta.faces.context.ExternalContext;
import jakarta.faces.context.FacesContext;
import jakarta.faces.event.ComponentSystemEvent;
import jakarta.inject.Inject;
import jakarta.inject.Named;

@Named
@RequestScoped
public class PostRenderViewEventBean {

    @Inject
    private FacesContext facesContext;
    
    @Inject
    private ExternalContext externalContext;

    public void pre(ComponentSystemEvent event) throws IOException {
        facesContext.setResponseWriter(facesContext.getRenderKit().createResponseWriter(externalContext.getResponseOutputWriter(), "text/html", "UTF-8"));
        facesContext.getResponseWriter().write("<!-- pre -->");
    }

    public String getRender() {
        return "render";
    }

    public void post(ComponentSystemEvent event) throws IOException {
        facesContext.getResponseWriter().write("<!-- post -->");
    }
}
